# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/image.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from is_msgs import validate_pb2 as is__msgs_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13is_msgs/image.proto\x12\tis.vision\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16is_msgs/validate.proto\"1\n\x05Image\x12\x0e\n\x04\x64\x61ta\x18\x01 \x01(\x0cH\x00\x12\r\n\x03uri\x18\x02 \x01(\tH\x00\x42\t\n\x07\x63ontent\"h\n\x0bImageFormat\x12\'\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x17.is.vision.ImageFormats\x12\x30\n\x0b\x63ompression\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\")\n\x06Vertex\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"3\n\x0c\x42oundingPoly\x12#\n\x08vertices\x18\x01 \x03(\x0b\x32\x11.is.vision.Vertex\"+\n\nResolution\x12\x0e\n\x06height\x18\x01 \x01(\r\x12\r\n\x05width\x18\x02 \x01(\r\"3\n\nColorSpace\x12%\n\x05value\x18\x01 \x01(\x0e\x32\x16.is.vision.ColorSpaces\"\xb7\x01\n\rImageSettings\x12)\n\nresolution\x18\x01 \x01(\x0b\x32\x15.is.vision.Resolution\x12&\n\x06\x66ormat\x18\x02 \x01(\x0b\x32\x16.is.vision.ImageFormat\x12*\n\x0b\x63olor_space\x18\x03 \x01(\x0b\x32\x15.is.vision.ColorSpace\x12\'\n\x06region\x18\x04 \x01(\x0b\x32\x17.is.vision.BoundingPoly\"d\n\x0fPointAnnotation\x12\n\n\x02id\x18\x01 \x01(\x03\x12 \n\x05score\x18\x02 \x01(\x02\x42\x11\xba\xe9\xc0\x03\x0c\n\n\x1d\x00\x00\x80?-\x00\x00\x00\x00\x12#\n\x08position\x18\x03 \x01(\x0b\x32\x11.is.vision.Vertex\"\xa7\x01\n\x10ObjectAnnotation\x12\r\n\x05label\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x03\x12 \n\x05score\x18\x03 \x01(\x02\x42\x11\xba\xe9\xc0\x03\x0c\n\n\x1d\x00\x00\x80?-\x00\x00\x00\x00\x12\'\n\x06region\x18\x04 \x01(\x0b\x32\x17.is.vision.BoundingPoly\x12-\n\tkeypoints\x18\x05 \x03(\x0b\x32\x1a.is.vision.PointAnnotation\"~\n\x11ObjectAnnotations\x12,\n\x07objects\x18\x01 \x03(\x0b\x32\x1b.is.vision.ObjectAnnotation\x12)\n\nresolution\x18\x02 \x01(\x0b\x32\x15.is.vision.Resolution\x12\x10\n\x08\x66rame_id\x18\x03 \x01(\x03*+\n\x0cImageFormats\x12\x07\n\x03PNG\x10\x00\x12\x08\n\x04JPEG\x10\x01\x12\x08\n\x04WebP\x10\x02*4\n\x0b\x43olorSpaces\x12\x07\n\x03RGB\x10\x00\x12\x08\n\x04GRAY\x10\x01\x12\t\n\x05YCbCr\x10\x02\x12\x07\n\x03HSV\x10\x03*\xd5\x02\n\x0eHumanKeypoints\x12\x1a\n\x16UNKNOWN_HUMAN_KEYPOINT\x10\x00\x12\x08\n\x04HEAD\x10\x01\x12\x08\n\x04NOSE\x10\x02\x12\x08\n\x04NECK\x10\x03\x12\x12\n\x0eRIGHT_SHOULDER\x10\x04\x12\x0f\n\x0bRIGHT_ELBOW\x10\x05\x12\x0f\n\x0bRIGHT_WRIST\x10\x06\x12\x11\n\rLEFT_SHOULDER\x10\x07\x12\x0e\n\nLEFT_ELBOW\x10\x08\x12\x0e\n\nLEFT_WRIST\x10\t\x12\r\n\tRIGHT_HIP\x10\n\x12\x0e\n\nRIGHT_KNEE\x10\x0b\x12\x0f\n\x0bRIGHT_ANKLE\x10\x0c\x12\x0c\n\x08LEFT_HIP\x10\r\x12\r\n\tLEFT_KNEE\x10\x0e\x12\x0e\n\nLEFT_ANKLE\x10\x0f\x12\r\n\tRIGHT_EYE\x10\x10\x12\x0c\n\x08LEFT_EYE\x10\x11\x12\r\n\tRIGHT_EAR\x10\x12\x12\x0c\n\x08LEFT_EAR\x10\x13\x12\t\n\x05\x43HEST\x10\x14*6\n\x0cObjectLabels\x12\x12\n\x0eUNKNOWN_OBJECT\x10\x00\x12\x12\n\x0eHUMAN_SKELETON\x10\x01\x42\x11\n\rcom.is.visionP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'is_msgs.image_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\rcom.is.visionP\001'
  _POINTANNOTATION.fields_by_name['score']._options = None
  _POINTANNOTATION.fields_by_name['score']._serialized_options = b'\272\351\300\003\014\n\n\035\000\000\200?-\000\000\000\000'
  _OBJECTANNOTATION.fields_by_name['score']._options = None
  _OBJECTANNOTATION.fields_by_name['score']._serialized_options = b'\272\351\300\003\014\n\n\035\000\000\200?-\000\000\000\000'
  _IMAGEFORMATS._serialized_start=1027
  _IMAGEFORMATS._serialized_end=1070
  _COLORSPACES._serialized_start=1072
  _COLORSPACES._serialized_end=1124
  _HUMANKEYPOINTS._serialized_start=1127
  _HUMANKEYPOINTS._serialized_end=1468
  _OBJECTLABELS._serialized_start=1470
  _OBJECTLABELS._serialized_end=1524
  _IMAGE._serialized_start=90
  _IMAGE._serialized_end=139
  _IMAGEFORMAT._serialized_start=141
  _IMAGEFORMAT._serialized_end=245
  _VERTEX._serialized_start=247
  _VERTEX._serialized_end=288
  _BOUNDINGPOLY._serialized_start=290
  _BOUNDINGPOLY._serialized_end=341
  _RESOLUTION._serialized_start=343
  _RESOLUTION._serialized_end=386
  _COLORSPACE._serialized_start=388
  _COLORSPACE._serialized_end=439
  _IMAGESETTINGS._serialized_start=442
  _IMAGESETTINGS._serialized_end=625
  _POINTANNOTATION._serialized_start=627
  _POINTANNOTATION._serialized_end=727
  _OBJECTANNOTATION._serialized_start=730
  _OBJECTANNOTATION._serialized_end=897
  _OBJECTANNOTATIONS._serialized_start=899
  _OBJECTANNOTATIONS._serialized_end=1025
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/tests.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from is_msgs import validate_pb2 as is__msgs_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13is_msgs/tests.proto\x12\x08is.tests\x1a\x16is_msgs/validate.proto\"s\n\x03\x46oo\x12$\n\x05myint\x18\x01 \x01(\x05\x42\x15\xba\xe9\xc0\x03\x10\x1a\x0e\x18\xd0\x0f(\xce\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\"\n\x07myfloat\x18\x02 \x01(\x02\x42\x11\xba\xe9\xc0\x03\x0c\n\n\x15\x9a\x99\x99>%\xcd\xcc\xcc=\x12\"\n\x08mydouble\x18\x03 \x01(\x01\x42\x10\xba\xe9\xc0\x03\x0b\x12\t\x19\xb4\xc8v\xbe\x9f\xaa@@\"B\n\x03\x42\x61r\x12\x1c\n\x05myfoo\x18\x01 \x01(\x0b\x32\r.is.tests.Foo\x12\x1d\n\x07myfloat\x18\x02 \x01(\x02\x42\x0c\xba\xe9\xc0\x03\x07\n\x05%\x00\x00\x80\xbf\"\x87\x02\n\x07Repeats\x12\x1b\n\x04\x66oos\x18\x01 \x03(\x0b\x32\r.is.tests.Foo\x12\'\n\x04\x66oo2\x18\x02 \x01(\x0b\x32\r.is.tests.FooB\n\xba\xe9\xc0\x03\x05\x8a\x01\x02\x10\x01\x12\"\n\x06int32s\x18\x03 \x03(\x05\x42\x12\xba\xe9\xc0\x03\r\x1a\x0b\x10\xf6\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1a\n\x07uint32s\x18\x04 \x03(\rB\t\xba\xe9\xc0\x03\x04*\x02 \n\x12\x1c\n\x06\x66loats\x18\x05 \x03(\x02\x42\x0c\xba\xe9\xc0\x03\x07\n\x05\x1d\x00\x00 \xc1\x12!\n\x07\x64oubles\x18\x06 \x03(\x01\x42\x10\xba\xe9\xc0\x03\x0b\x12\t)\x00\x00\x00\x00\x00\x00$\xc0\x12\x19\n\x06int64s\x18\x07 \x03(\x03\x42\t\xba\xe9\xc0\x03\x04\"\x02\x10\n\x12\x1a\n\x07uint64s\x18\x08 \x03(\x04\x42\t\xba\xe9\xc0\x03\x04\x32\x02 db\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'is_msgs.tests_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FOO.fields_by_name['myint']._options = None
  _FOO.fields_by_name['myint']._serialized_options = b'\272\351\300\003\020\032\016\030\320\017(\316\377\377\377\377\377\377\377\377\001'
  _FOO.fields_by_name['myfloat']._options = None
  _FOO.fields_by_name['myfloat']._serialized_options = b'\272\351\300\003\014\n\n\025\232\231\231>%\315\314\314='
  _FOO.fields_by_name['mydouble']._options = None
  _FOO.fields_by_name['mydouble']._serialized_options = b'\272\351\300\003\013\022\t\031\264\310v\276\237\252@@'
  _BAR.fields_by_name['myfloat']._options = None
  _BAR.fields_by_name['myfloat']._serialized_options = b'\272\351\300\003\007\n\005%\000\000\200\277'
  _REPEATS.fields_by_name['foo2']._options = None
  _REPEATS.fields_by_name['foo2']._serialized_options = b'\272\351\300\003\005\212\001\002\020\001'
  _REPEATS.fields_by_name['int32s']._options = None
  _REPEATS.fields_by_name['int32s']._serialized_options = b'\272\351\300\003\r\032\013\020\366\377\377\377\377\377\377\377\377\001'
  _REPEATS.fields_by_name['uint32s']._options = None
  _REPEATS.fields_by_name['uint32s']._serialized_options = b'\272\351\300\003\004*\002 \n'
  _REPEATS.fields_by_name['floats']._options = None
  _REPEATS.fields_by_name['floats']._serialized_options = b'\272\351\300\003\007\n\005\035\000\000 \301'
  _REPEATS.fields_by_name['doubles']._options = None
  _REPEATS.fields_by_name['doubles']._serialized_options = b'\272\351\300\003\013\022\t)\000\000\000\000\000\000$\300'
  _REPEATS.fields_by_name['int64s']._options = None
  _REPEATS.fields_by_name['int64s']._serialized_options = b'\272\351\300\003\004\"\002\020\n'
  _REPEATS.fields_by_name['uint64s']._options = None
  _REPEATS.fields_by_name['uint64s']._serialized_options = b'\272\351\300\003\0042\002 d'
  _FOO._serialized_start=57
  _FOO._serialized_end=172
  _BAR._serialized_start=174
  _BAR._serialized_end=240
  _REPEATS._serialized_start=243
  _REPEATS._serialized_end=506
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/power.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13is_msgs/power.proto\x12\tis.common\x1a\x1egoogle/protobuf/duration.proto\"\xbc\x03\n\tPowerInfo\x12\x0f\n\x07voltage\x18\x01 \x01(\x02\x12\x18\n\x10terminal_voltage\x18\x02 \x01(\x02\x12\x14\n\x0c\x63\x65ll_voltage\x18\x03 \x03(\x02\x12\x0e\n\x06\x63harge\x18\x04 \x01(\x02\x12\x10\n\x08\x63\x61pacity\x18\x05 \x01(\x02\x12.\n\x04type\x18\x06 \x01(\x0e\x32 .is.common.PowerInfo.BatteryType\x12\x32\n\x06status\x18\x07 \x01(\x0e\x32\".is.common.PowerInfo.BatteryStatus\x12)\n\x06uptime\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x61utonomy\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration\"3\n\x0b\x42\x61tteryType\x12\x06\n\x02PB\x10\x00\x12\x08\n\x04NICD\x10\x01\x12\x08\n\x04NIMH\x10\x02\x12\x08\n\x04LIPO\x10\x03\"[\n\rBatteryStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08\x43HARGING\x10\x01\x12\x0f\n\x0b\x44ISCHARGING\x10\x02\x12\x0b\n\x07\x43HARGED\x10\x03\x12\x11\n\rNOT_CONNECTED\x10\x04\x42\x11\n\rcom.is.commonP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'is_msgs.power_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\rcom.is.commonP\001'
  _POWERINFO._serialized_start=67
  _POWERINFO._serialized_end=511
  _POWERINFO_BATTERYTYPE._serialized_start=367
  _POWERINFO_BATTERYTYPE._serialized_end=418
  _POWERINFO_BATTERYSTATUS._serialized_start=420
  _POWERINFO_BATTERYSTATUS._serialized_end=511
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/camera.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from is_msgs import common_pb2 as is__msgs_dot_common__pb2
from is_msgs import image_pb2 as is__msgs_dot_image__pb2
from is_msgs import validate_pb2 as is__msgs_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14is_msgs/camera.proto\x12\tis.vision\x1a\x14is_msgs/common.proto\x1a\x13is_msgs/image.proto\x1a\x16is_msgs/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"T\n\rCameraSetting\x12\x11\n\tautomatic\x18\x01 \x01(\x08\x12 \n\x05ratio\x18\x02 \x01(\x02\x42\x11\xba\xe9\xc0\x03\x0c\n\n\x1d\x00\x00\x80?-\x00\x00\x00\x00\x12\x0e\n\x06option\x18\x03 \x01(\t\"\xf5\x04\n\x0e\x43\x61meraSettings\x12,\n\nbrightness\x18\x01 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12*\n\x08\x65xposure\x18\x02 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12\'\n\x05\x66ocus\x18\x03 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12&\n\x04gain\x18\x04 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12\'\n\x05gamma\x18\x05 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12%\n\x03hue\x18\x06 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12&\n\x04iris\x18\x07 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12,\n\nsaturation\x18\x08 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12+\n\tsharpness\x18\t \x01(\x0b\x32\x18.is.vision.CameraSetting\x12)\n\x07shutter\x18\n \x01(\x0b\x32\x18.is.vision.CameraSetting\x12\x32\n\x10white_balance_bu\x18\x0b \x01(\x0b\x32\x18.is.vision.CameraSetting\x12\x32\n\x10white_balance_rv\x18\x0c \x01(\x0b\x32\x18.is.vision.CameraSetting\x12&\n\x04zoom\x18\r \x01(\x0b\x32\x18.is.vision.CameraSetting\x12*\n\x08\x63ontrast\x18\x0e \x01(\x0b\x32\x18.is.vision.CameraSetting\"V\n\nPTZControl\x12%\n\x08\x61\x62solute\x18\x01 \x01(\x0b\x32\x13.is.common.Position\x12!\n\x04step\x18\x02 \x01(\x0b\x32\x13.is.common.Position\"\xa5\x02\n\x0c\x43\x61meraConfig\x12-\n\x08sampling\x18\x01 \x01(\x0b\x32\x1b.is.common.SamplingSettings\x12\'\n\x05image\x18\x02 \x01(\x0b\x32\x18.is.vision.ImageSettings\x12)\n\x06\x63\x61mera\x18\x03 \x01(\x0b\x32\x19.is.vision.CameraSettings\x12\x36\n\x11stream_channel_id\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12/\n\nchannel_id\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12)\n\nptzcontrol\x18\x06 \x01(\x0b\x32\x15.is.vision.PTZControl\"\x8c\x02\n\x11\x43\x61meraCalibration\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x31\n\rcalibrated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05\x65rror\x18\x03 \x01(\x01\x12)\n\nresolution\x18\x04 \x01(\x0b\x32\x15.is.vision.Resolution\x12$\n\tintrinsic\x18\x05 \x01(\x0b\x32\x11.is.common.Tensor\x12%\n\ndistortion\x18\x06 \x01(\x0b\x32\x11.is.common.Tensor\x12\x31\n\textrinsic\x18\x07 \x03(\x0b\x32\x1e.is.vision.FrameTransformation\"~\n\x13\x46rameTransformation\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x03\x12\n\n\x02to\x18\x02 \x01(\x03\x12\x1d\n\x02tf\x18\x03 \x01(\x0b\x32\x11.is.common.Tensor\x12.\n\nexpiration\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"C\n\x14\x46rameTransformations\x12+\n\x03tfs\x18\x01 \x03(\x0b\x32\x1e.is.vision.FrameTransformation\"\"\n\x06IdPair\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x03\x12\n\n\x02to\x18\x02 \x01(\x03\":\n\x18GetTransformationRequest\x12\x1e\n\x03ids\x18\x01 \x03(\x0b\x32\x11.is.vision.IdPair\"Q\n\x16GetTransformationReply\x12\x37\n\x0ftransformations\x18\x01 \x03(\x0b\x32\x1e.is.vision.FrameTransformation\"\x1a\n\x18\x41\x64\x64TransformationRequest\"\x18\n\x16\x41\x64\x64TransformationReply\"$\n\x15GetCalibrationRequest\x12\x0b\n\x03ids\x18\x01 \x03(\x03\"I\n\x13GetCalibrationReply\x12\x32\n\x0c\x63\x61librations\x18\x01 \x03(\x0b\x32\x1c.is.vision.CameraCalibration*\x9d\x01\n\x12\x43\x61meraConfigFields\x12\x07\n\x03\x41LL\x10\x00\x12\x15\n\x11SAMPLING_SETTINGS\x10\x01\x12\x12\n\x0eIMAGE_SETTINGS\x10\x02\x12\x13\n\x0f\x43\x41MERA_SETTINGS\x10\x03\x12\x15\n\x11STREAM_CHANNEL_ID\x10\x04\x12\x0e\n\nCHANNEL_ID\x10\x05\x12\x17\n\x13PTZCONTROL_SETTINGS\x10\x06\x42\x11\n\rcom.is.visionP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'is_msgs.camera_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\rcom.is.visionP\001'
  _CAMERASETTING.fields_by_name['ratio']._options = None
  _CAMERASETTING.fields_by_name['ratio']._serialized_options = b'\272\351\300\003\014\n\n\035\000\000\200?-\000\000\000\000'
  _CAMERACONFIGFIELDS._serialized_start=2084
  _CAMERACONFIGFIELDS._serialized_end=2241
  _CAMERASETTING._serialized_start=167
  _CAMERASETTING._serialized_end=251
  _CAMERASETTINGS._serialized_start=254
  _CAMERASETTINGS._serialized_end=883
  _PTZCONTROL._serialized_start=885
  _PTZCONTROL._serialized_end=971
  _CAMERACONFIG._serialized_start=974
  _CAMERACONFIG._serialized_end=1267
  _CAMERACALIBRATION._serialized_start=1270
  _CAMERACALIBRATION._serialized_end=1538
  _FRAMETRANSFORMATION._serialized_start=1540
  _FRAMETRANSFORMATION._serialized_end=1666
  _FRAMETRANSFORMATIONS._serialized_start=1668
  _FRAMETRANSFORMATIONS._serialized_end=1735
  _IDPAIR._serialized_start=1737
  _IDPAIR._serialized_end=1771
  _GETTRANSFORMATIONREQUEST._serialized_start=1773
  _GETTRANSFORMATIONREQUEST._serialized_end=1831
  _GETTRANSFORMATIONREPLY._serialized_start=1833
  _GETTRANSFORMATIONREPLY._serialized_end=1914
  _ADDTRANSFORMATIONREQUEST._serialized_start=1916
  _ADDTRANSFORMATIONREQUEST._serialized_end=1942
  _ADDTRANSFORMATIONREPLY._serialized_start=1944
  _ADDTRANSFORMATIONREPLY._serialized_end=1968
  _GETCALIBRATIONREQUEST._serialized_start=1970
  _GETCALIBRATIONREQUEST._serialized_end=2006
  _GETCALIBRATIONREPLY._serialized_start=2008
  _GETCALIBRATIONREPLY._serialized_end=2081
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14is_msgs/common.proto\x12\tis.common\x1a\x1egoogle/protobuf/wrappers.proto\"n\n\x10SamplingSettings\x12.\n\tfrequency\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12*\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"N\n\x0bSyncRequest\x12\x10\n\x08\x65ntities\x18\x01 \x03(\t\x12-\n\x08sampling\x18\x02 \x01(\x0b\x32\x1b.is.common.SamplingSettings\"\x1f\n\rFieldSelector\x12\x0e\n\x06\x66ields\x18\x01 \x03(\r\"Z\n\x05Shape\x12(\n\x04\x64ims\x18\x01 \x03(\x0b\x32\x1a.is.common.Shape.Dimension\x1a\'\n\tDimension\x12\x0c\n\x04size\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x9d\x01\n\x06Tensor\x12\x1f\n\x05shape\x18\x01 \x01(\x0b\x32\x10.is.common.Shape\x12!\n\x04type\x18\x02 \x01(\x0e\x32\x13.is.common.DataType\x12\x12\n\x06\x66loats\x18\x03 \x03(\x02\x42\x02\x10\x01\x12\x13\n\x07\x64oubles\x18\x04 \x03(\x01\x42\x02\x10\x01\x12\x12\n\x06ints32\x18\x05 \x03(\x05\x42\x02\x10\x01\x12\x12\n\x06ints64\x18\x06 \x03(\x03\x42\x02\x10\x01\"+\n\x08Position\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"7\n\x0bOrientation\x12\x0b\n\x03yaw\x18\x01 \x01(\x02\x12\r\n\x05pitch\x18\x02 \x01(\x02\x12\x0c\n\x04roll\x18\x03 \x01(\x02\"Z\n\x04Pose\x12%\n\x08position\x18\x01 \x01(\x0b\x32\x13.is.common.Position\x12+\n\x0borientation\x18\x02 \x01(\x0b\x32\x16.is.common.Orientation\"(\n\x05Speed\x12\x0e\n\x06linear\x18\x01 \x01(\x02\x12\x0f\n\x07\x61ngular\x18\x02 \x01(\x02\"!\n\x0c\x43onsumerInfo\x12\x11\n\tconsumers\x18\x02 \x03(\t\"\x85\x01\n\x0c\x43onsumerList\x12/\n\x04info\x18\x01 \x03(\x0b\x32!.is.common.ConsumerList.InfoEntry\x1a\x44\n\tInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.is.common.ConsumerInfo:\x02\x38\x01\"?\n\x06Phrase\x12\x0f\n\x07\x63ontent\x18\x01 \x03(\t\x12\x12\n\nconfidence\x18\x02 \x01(\x02\x12\x10\n\x08language\x18\x03 \x01(\t*]\n\x08\x44\x61taType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x0e\n\nFLOAT_TYPE\x10\x01\x12\x0f\n\x0b\x44OUBLE_TYPE\x10\x02\x12\x0e\n\nINT32_TYPE\x10\x03\x12\x0e\n\nINT64_TYPE\x10\x04\x42\x11\n\rcom.is.commonP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'is_msgs.common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\rcom.is.commonP\001'
  _TENSOR.fields_by_name['floats']._options = None
  _TENSOR.fields_by_name['floats']._serialized_options = b'\020\001'
  _TENSOR.fields_by_name['doubles']._options = None
  _TENSOR.fields_by_name['doubles']._serialized_options = b'\020\001'
  _TENSOR.fields_by_name['ints32']._options = None
  _TENSOR.fields_by_name['ints32']._serialized_options = b'\020\001'
  _TENSOR.fields_by_name['ints64']._options = None
  _TENSOR.fields_by_name['ints64']._serialized_options = b'\020\001'
  _CONSUMERLIST_INFOENTRY._options = None
  _CONSUMERLIST_INFOENTRY._serialized_options = b'8\001'
  _DATATYPE._serialized_start=1016
  _DATATYPE._serialized_end=1109
  _SAMPLINGSETTINGS._serialized_start=67
  _SAMPLINGSETTINGS._serialized_end=177
  _SYNCREQUEST._serialized_start=179
  _SYNCREQUEST._serialized_end=257
  _FIELDSELECTOR._serialized_start=259
  _FIELDSELECTOR._serialized_end=290
  _SHAPE._serialized_start=292
  _SHAPE._serialized_end=382
  _SHAPE_DIMENSION._serialized_start=343
  _SHAPE_DIMENSION._serialized_end=382
  _TENSOR._serialized_start=385
  _TENSOR._serialized_end=542
  _POSITION._serialized_start=544
  _POSITION._serialized_end=587
  _ORIENTATION._serialized_start=589
  _ORIENTATION._serialized_end=644
  _POSE._serialized_start=646
  _POSE._serialized_end=736
  _SPEED._serialized_start=738
  _SPEED._serialized_end=778
  _CONSUMERINFO._serialized_start=780
  _CONSUMERINFO._serialized_end=813
  _CONSUMERLIST._serialized_start=816
  _CONSUMERLIST._serialized_end=949
  _CONSUMERLIST_INFOENTRY._serialized_start=881
  _CONSUMERLIST_INFOENTRY._serialized_end=949
  _PHRASE._serialized_start=951
  _PHRASE._serialized_end=1014
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/robot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from is_msgs import common_pb2 as is__msgs_dot_common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13is_msgs/robot.proto\x12\x08is.robot\x1a\x14is_msgs/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"+\n\tRangeScan\x12\x0e\n\x06\x61ngles\x18\x01 \x03(\x02\x12\x0e\n\x06ranges\x18\x02 \x03(\x02\".\n\x0bRobotConfig\x12\x1f\n\x05speed\x18\x01 \x01(\x0b\x32\x10.is.common.Speed\"\xb1\x01\n\rBasicMoveTask\x12&\n\tpositions\x18\x01 \x03(\x0b\x32\x13.is.common.Position\x12 \n\x06speeds\x18\x02 \x03(\x0b\x32\x10.is.common.Speed\x12\x31\n\x11\x66inal_orientation\x18\x03 \x01(\x0b\x32\x16.is.common.Orientation\x12\x15\n\rallowed_error\x18\x04 \x01(\x02\x12\x0c\n\x04rate\x18\x05 \x01(\x02\"Z\n\x10RobotTaskRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x32\n\x0f\x62\x61sic_move_task\x18\x02 \x01(\x0b\x32\x17.is.robot.BasicMoveTaskH\x00\x42\x06\n\x04Task\"\x1c\n\x0eRobotTaskReply\x12\n\n\x02id\x18\x01 \x01(\x04\"\xa4\x02\n\x17RobotControllerProgress\x12\n\n\x02id\x18\t \x01(\x04\x12\'\n\rcurrent_speed\x18\x01 \x01(\x0b\x32\x10.is.common.Speed\x12%\n\x0c\x63urrent_pose\x18\x02 \x01(\x0b\x32\x0f.is.common.Pose\x12%\n\x0c\x64\x65sired_pose\x18\x03 \x01(\x0b\x32\x0f.is.common.Pose\x12\r\n\x05\x65rror\x18\x04 \x01(\x02\x12\x12\n\ncompletion\x18\x05 \x01(\x02\x12\x0f\n\x07sources\x18\x06 \x03(\t\x12)\n\x05\x62\x65gin\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x83\x01\n\x0bPathRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12)\n\x10\x64\x65stination_pose\x18\x02 \x01(\x0b\x32\x0f.is.common.Pose\x12\x18\n\x10robot_gateway_id\x18\x03 \x01(\x04\x12\x0c\n\x04rate\x18\x04 \x01(\x02\x12\x15\n\rallowed_error\x18\x05 \x01(\x02\x42\x10\n\x0c\x63om.is.robotP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'is_msgs.robot_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\014com.is.robotP\001'
  _RANGESCAN._serialized_start=88
  _RANGESCAN._serialized_end=131
  _ROBOTCONFIG._serialized_start=133
  _ROBOTCONFIG._serialized_end=179
  _BASICMOVETASK._serialized_start=182
  _BASICMOVETASK._serialized_end=359
  _ROBOTTASKREQUEST._serialized_start=361
  _ROBOTTASKREQUEST._serialized_end=451
  _ROBOTTASKREPLY._serialized_start=453
  _ROBOTTASKREPLY._serialized_end=481
  _ROBOTCONTROLLERPROGRESS._serialized_start=484
  _ROBOTCONTROLLERPROGRESS._serialized_end=776
  _PATHREQUEST._serialized_start=779
  _PATHREQUEST._serialized_end=910
# @@protoc_insertion_point(module_scope)



import os
import sys
import re
import shutil
import subprocess
import urllib.request
import zipfile
import tarfile

from distutils.cmd import Command
from distutils.dir_util import copy_tree, remove_tree
from setuptools.command.install import install
from setuptools.command.sdist import sdist
from setuptools import setup


PKG_DIR = '.'
PKG_NAME = 'is_msgs'
PROTO_DIR = '../src/'
PKG_VERSION_PATTERN = r"^[0-9]+\.[0-9]+\.[0-9]+$"
PKG_VERSION = '1.1.18'

if re.match(PKG_VERSION_PATTERN, PKG_VERSION) is None:
    raise RuntimeError(
            "Package version must matches the pattern '{}'".format(PKG_VERSION_PATTERN))

major_depencies_list = ['wheel']

for package in major_depencies_list:
    if package not in sys.modules:
        python = sys.executable
        subprocess.check_call([python, '-m', 'pip', 'install', package], stdout=subprocess.DEVNULL)


class MyZipFile(zipfile.ZipFile):
    """
        Modification necessary to keep execution permission
        on files aftar extract *.zip files

        source: https://stackoverflow.com/questions/39296101/python-zipfile-removes-execute-permissions-from-binaries
    """

    def extract(self, member, path=None, pwd=None):
        if not isinstance(member, zipfile.ZipInfo):
            member = self.getinfo(member)

        if path is None:
            path = os.getcwd()

        ret_val = self._extract_member(member, path, pwd)
        attr = member.external_attr >> 16
        if attr != 0:
            os.chmod(ret_val, attr)
        return ret_val

    def extractall(self, path=None, members=None, pwd=None):
        if members is None:
            members = self.namelist()

        if path is None:
            path = os.getcwd()
        else:
            path = os.fspath(path)

        for zipinfo in members:
            self.extract(zipinfo, path, pwd)


def download_file(filename, url):
    urllib.request.urlretrieve(url, filename)


def download_protoc():

    PROTOC_VERSION = '3.20.3'
    PROTOC_ZIP_FILE = 'protoc-{}-linux-x86_64.zip'.format(PROTOC_VERSION)
    PROTOC_BASE_URL = 'https://github.com/google/protobuf/releases/download/v{}/{}'
    PROTOC_URL = PROTOC_BASE_URL.format(PROTOC_VERSION, PROTOC_ZIP_FILE)

    download_file(PROTOC_ZIP_FILE, PROTOC_URL)
    protoc_zip = MyZipFile(PROTOC_ZIP_FILE, 'r')
    protoc_zip.extractall(path='protoc')
    protoc_zip.close()


def download_protoc_gen_doc():

    PLUGIN_VERSION = '1.1.0'
    GOLANG_VERSION = '1.10'
    PLUGIN_TAR_FILE = 'protoc-gen-doc-{}.linux-amd64.go{}.tar.gz'.format(
        PLUGIN_VERSION, GOLANG_VERSION)
    PLUGIN_BASE_URL = "https://github.com/pseudomuto/protoc-gen-doc/releases/download/v{}/{}"
    PLUGIN_URL = PLUGIN_BASE_URL.format(PLUGIN_VERSION, PLUGIN_TAR_FILE)

    download_file(PLUGIN_TAR_FILE, PLUGIN_URL)
    plugin_tar = tarfile.open(name=PLUGIN_TAR_FILE, mode='r:gz')
    plugin_tar.extractall()
    plugin_tar.close()

    extracted_folder = PLUGIN_TAR_FILE.replace('.tar.gz', '')
    copy_tree(extracted_folder, 'protoc-gen-doc')
    remove_tree(extracted_folder)


class InstallWrapper(install):

    pkg_path = os.path.join(PKG_DIR, PKG_NAME)

    def run(self):
        # Run this first so the install stops in case  these fail otherwise
        # the Python package is successfully installed
        self._compile_protobufs()
        # Run the standard PyPi copy
        install.run(self)

    def _compile_protobufs(self):
        download_protoc()
        self._clean_pkg_folder()
        protos = self._transform_proto_files()
        self._run_protoc_command(PKG_DIR, protos)
        self._patch_artifacts()

    def _patch_artifacts(self):
        artifacts = self._list_pb2_artifacts()
        for artifact in artifacts:
            artifact_file_path = os.path.join(self.pkg_path, artifact)
            with open(artifact_file_path, 'r') as f:
                output = re.sub(r'([^ ]import) ([a-zA-Z]+[\w]*_pb2[ as])', r'\1 is_msgs.\2',
                                f.read())
            with open(artifact_file_path, 'w') as f:
                f.write(output)

    def _list_pb2_artifacts(self):
        return [f for f in os.listdir(self.pkg_path) if f.endswith('pb2.py')]

    def _run_protoc_command(self, base_dir, protos):
        protos_str_list = ' '.join(protos)
        protoc_command = """
        ./protoc/bin/protoc    \
            -I./protoc/include \
            --proto_path={}    \
            --python_out={} {}""".format(base_dir, base_dir, protos_str_list)
        subprocess.call(['bash', '-c', protoc_command])

    def _list_proto_files(self):
        if os.path.exists(PROTO_DIR):
            proto_files_path = os.path.join(PROTO_DIR, 'is/msgs')
        else:
            proto_files_path = os.path.join(PKG_DIR, 'is_msgs')
        protos = [f for f in os.listdir(proto_files_path) if f.endswith('.proto')]
        return protos, proto_files_path

    def _transform_proto_files(self):

        protos, proto_files_path = self._list_proto_files()
        for proto in protos:
            shutil.copy(os.path.join(proto_files_path, proto), self.pkg_path)
            proto_pkg_path = os.path.join(self.pkg_path, proto)
            with open(proto_pkg_path, 'r') as f:
                output = re.sub(r'import "is/msgs/*', r'import "is_msgs/', f.read())
            with open(proto_pkg_path, 'w') as f:
                f.write(output)

        return [os.path.join(self.pkg_path, proto) for proto in protos]

    def _clean_pkg_folder(self):
        pkg_path = os.path.join(PKG_DIR, PKG_NAME)

        old_artifacts = self._list_pb2_artifacts()
        old_proto_files = [f for f in os.listdir(pkg_path) if f.endswith('.proto')]
        for f in old_artifacts + old_proto_files:
            os.remove(os.path.join(pkg_path, f))


class ProtobufDocumentationCommand(Command):

    user_options = []
    description = "Generates protobuf's documentation"

    def initialize_options(self):
        self.doc_builder = ProtobufDocumentation()
        self.doc_builder.download_tools()

    def finalize_options(self):
        pass

    def run(self):
        self.doc_builder.build()


class ProtobufDocumentation():

    def download_tools(self):
        download_protoc()
        download_protoc_gen_doc()

    def build(self):
        proto_files_path = os.path.join(PROTO_DIR, 'is/msgs/')
        proto_files_path += "*.proto"
        protoc_command = """
        ./protoc/bin/protoc                                         \
            --plugin=protoc-gen-doc=./protoc-gen-doc/protoc-gen-doc \
            --doc_out=../docs/ \
            --doc_opt=markdown,README.md \
            -I./{} \
            {}""".format(PROTO_DIR, proto_files_path)
        subprocess.call(['bash', '-c', protoc_command])


class DistributedWithDocs(sdist):
    """Custom build command."""

    def run(self):
        self.doc_builder = ProtobufDocumentation()
        self.doc_builder.download_tools()
        self.doc_builder.build()
        sdist.run(self)


setup(
    name=PKG_NAME,
    version=PKG_VERSION,
    description='Package with standard IS messages',
    long_description=open("README.md").read().strip(),
    long_description_content_type="text/markdown",
    url='http://github.com/labvisio/is-msgs',
    author='labvisio',
    author_email='labvisio.ufes@gmail.com',
    license='MIT',
    classifiers=[
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3 :: Only',
    ],
    package_dir={'': PKG_DIR},
    packages=[PKG_NAME, PKG_NAME + '.utils'],
    package_data={PKG_NAME: ['*.proto']},
    zip_safe=False,
    install_requires=['protobuf==3.20.3'],
    cmdclass={
        'install': InstallWrapper,
        'sdist': DistributedWithDocs,
        'build_proto_doc': ProtobufDocumentationCommand,
    },
)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/validate.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16is_msgs/validate.proto\x12\x0bis.validate\x1a google/protobuf/descriptor.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdc\x07\n\nFieldRules\x12(\n\x05\x66loat\x18\x01 \x01(\x0b\x32\x17.is.validate.FloatRulesH\x00\x12*\n\x06\x64ouble\x18\x02 \x01(\x0b\x32\x18.is.validate.DoubleRulesH\x00\x12(\n\x05int32\x18\x03 \x01(\x0b\x32\x17.is.validate.Int32RulesH\x00\x12(\n\x05int64\x18\x04 \x01(\x0b\x32\x17.is.validate.Int64RulesH\x00\x12*\n\x06uint32\x18\x05 \x01(\x0b\x32\x18.is.validate.UInt32RulesH\x00\x12*\n\x06uint64\x18\x06 \x01(\x0b\x32\x18.is.validate.UInt64RulesH\x00\x12*\n\x06sint32\x18\x07 \x01(\x0b\x32\x18.is.validate.SInt32RulesH\x00\x12*\n\x06sint64\x18\x08 \x01(\x0b\x32\x18.is.validate.SInt64RulesH\x00\x12,\n\x07\x66ixed32\x18\t \x01(\x0b\x32\x19.is.validate.Fixed32RulesH\x00\x12,\n\x07\x66ixed64\x18\n \x01(\x0b\x32\x19.is.validate.Fixed64RulesH\x00\x12.\n\x08sfixed32\x18\x0b \x01(\x0b\x32\x1a.is.validate.SFixed32RulesH\x00\x12.\n\x08sfixed64\x18\x0c \x01(\x0b\x32\x1a.is.validate.SFixed64RulesH\x00\x12&\n\x04\x62ool\x18\r \x01(\x0b\x32\x16.is.validate.BoolRulesH\x00\x12*\n\x06string\x18\x0e \x01(\x0b\x32\x18.is.validate.StringRulesH\x00\x12(\n\x05\x62ytes\x18\x0f \x01(\x0b\x32\x17.is.validate.BytesRulesH\x00\x12&\n\x04\x65num\x18\x10 \x01(\x0b\x32\x16.is.validate.EnumRulesH\x00\x12,\n\x07message\x18\x11 \x01(\x0b\x32\x19.is.validate.MessageRulesH\x00\x12.\n\x08repeated\x18\x12 \x01(\x0b\x32\x1a.is.validate.RepeatedRulesH\x00\x12$\n\x03map\x18\x13 \x01(\x0b\x32\x15.is.validate.MapRulesH\x00\x12$\n\x03\x61ny\x18\x14 \x01(\x0b\x32\x15.is.validate.AnyRulesH\x00\x12.\n\x08\x64uration\x18\x15 \x01(\x0b\x32\x1a.is.validate.DurationRulesH\x00\x12\x30\n\ttimestamp\x18\x16 \x01(\x0b\x32\x1b.is.validate.TimestampRulesH\x00\x42\x06\n\x04type\"i\n\nFloatRules\x12\r\n\x05\x63onst\x18\x01 \x01(\x02\x12\n\n\x02lt\x18\x02 \x01(\x02\x12\x0b\n\x03lte\x18\x03 \x01(\x02\x12\n\n\x02gt\x18\x04 \x01(\x02\x12\x0b\n\x03gte\x18\x05 \x01(\x02\x12\n\n\x02in\x18\x06 \x03(\x02\x12\x0e\n\x06not_in\x18\x07 \x03(\x02\"j\n\x0b\x44oubleRules\x12\r\n\x05\x63onst\x18\x01 \x01(\x01\x12\n\n\x02lt\x18\x02 \x01(\x01\x12\x0b\n\x03lte\x18\x03 \x01(\x01\x12\n\n\x02gt\x18\x04 \x01(\x01\x12\x0b\n\x03gte\x18\x05 \x01(\x01\x12\n\n\x02in\x18\x06 \x03(\x01\x12\x0e\n\x06not_in\x18\x07 \x03(\x01\"i\n\nInt32Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x05\x12\n\n\x02lt\x18\x02 \x01(\x05\x12\x0b\n\x03lte\x18\x03 \x01(\x05\x12\n\n\x02gt\x18\x04 \x01(\x05\x12\x0b\n\x03gte\x18\x05 \x01(\x05\x12\n\n\x02in\x18\x06 \x03(\x05\x12\x0e\n\x06not_in\x18\x07 \x03(\x05\"i\n\nInt64Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x03\x12\n\n\x02lt\x18\x02 \x01(\x03\x12\x0b\n\x03lte\x18\x03 \x01(\x03\x12\n\n\x02gt\x18\x04 \x01(\x03\x12\x0b\n\x03gte\x18\x05 \x01(\x03\x12\n\n\x02in\x18\x06 \x03(\x03\x12\x0e\n\x06not_in\x18\x07 \x03(\x03\"j\n\x0bUInt32Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\r\x12\n\n\x02lt\x18\x02 \x01(\r\x12\x0b\n\x03lte\x18\x03 \x01(\r\x12\n\n\x02gt\x18\x04 \x01(\r\x12\x0b\n\x03gte\x18\x05 \x01(\r\x12\n\n\x02in\x18\x06 \x03(\r\x12\x0e\n\x06not_in\x18\x07 \x03(\r\"j\n\x0bUInt64Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x04\x12\n\n\x02lt\x18\x02 \x01(\x04\x12\x0b\n\x03lte\x18\x03 \x01(\x04\x12\n\n\x02gt\x18\x04 \x01(\x04\x12\x0b\n\x03gte\x18\x05 \x01(\x04\x12\n\n\x02in\x18\x06 \x03(\x04\x12\x0e\n\x06not_in\x18\x07 \x03(\x04\"j\n\x0bSInt32Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x11\x12\n\n\x02lt\x18\x02 \x01(\x11\x12\x0b\n\x03lte\x18\x03 \x01(\x11\x12\n\n\x02gt\x18\x04 \x01(\x11\x12\x0b\n\x03gte\x18\x05 \x01(\x11\x12\n\n\x02in\x18\x06 \x03(\x11\x12\x0e\n\x06not_in\x18\x07 \x03(\x11\"j\n\x0bSInt64Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x12\x12\n\n\x02lt\x18\x02 \x01(\x12\x12\x0b\n\x03lte\x18\x03 \x01(\x12\x12\n\n\x02gt\x18\x04 \x01(\x12\x12\x0b\n\x03gte\x18\x05 \x01(\x12\x12\n\n\x02in\x18\x06 \x03(\x12\x12\x0e\n\x06not_in\x18\x07 \x03(\x12\"k\n\x0c\x46ixed32Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x07\x12\n\n\x02lt\x18\x02 \x01(\x07\x12\x0b\n\x03lte\x18\x03 \x01(\x07\x12\n\n\x02gt\x18\x04 \x01(\x07\x12\x0b\n\x03gte\x18\x05 \x01(\x07\x12\n\n\x02in\x18\x06 \x03(\x07\x12\x0e\n\x06not_in\x18\x07 \x03(\x07\"k\n\x0c\x46ixed64Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x06\x12\n\n\x02lt\x18\x02 \x01(\x06\x12\x0b\n\x03lte\x18\x03 \x01(\x06\x12\n\n\x02gt\x18\x04 \x01(\x06\x12\x0b\n\x03gte\x18\x05 \x01(\x06\x12\n\n\x02in\x18\x06 \x03(\x06\x12\x0e\n\x06not_in\x18\x07 \x03(\x06\"l\n\rSFixed32Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x0f\x12\n\n\x02lt\x18\x02 \x01(\x0f\x12\x0b\n\x03lte\x18\x03 \x01(\x0f\x12\n\n\x02gt\x18\x04 \x01(\x0f\x12\x0b\n\x03gte\x18\x05 \x01(\x0f\x12\n\n\x02in\x18\x06 \x03(\x0f\x12\x0e\n\x06not_in\x18\x07 \x03(\x0f\"l\n\rSFixed64Rules\x12\r\n\x05\x63onst\x18\x01 \x01(\x10\x12\n\n\x02lt\x18\x02 \x01(\x10\x12\x0b\n\x03lte\x18\x03 \x01(\x10\x12\n\n\x02gt\x18\x04 \x01(\x10\x12\x0b\n\x03gte\x18\x05 \x01(\x10\x12\n\n\x02in\x18\x06 \x03(\x10\x12\x0e\n\x06not_in\x18\x07 \x03(\x10\"\x1a\n\tBoolRules\x12\r\n\x05\x63onst\x18\x01 \x01(\x08\"\xc6\x02\n\x0bStringRules\x12\r\n\x05\x63onst\x18\x01 \x01(\t\x12\x0f\n\x07min_len\x18\x02 \x01(\x04\x12\x0f\n\x07max_len\x18\x03 \x01(\x04\x12\x11\n\tmin_bytes\x18\x04 \x01(\x04\x12\x11\n\tmax_bytes\x18\x05 \x01(\x04\x12\x0f\n\x07pattern\x18\x06 \x01(\t\x12\x0e\n\x06prefix\x18\x07 \x01(\t\x12\x0e\n\x06suffix\x18\x08 \x01(\t\x12\x10\n\x08\x63ontains\x18\t \x01(\t\x12\n\n\x02in\x18\n \x03(\t\x12\x0e\n\x06not_in\x18\x0b \x03(\t\x12\x0f\n\x05\x65mail\x18\x0c \x01(\x08H\x00\x12\x12\n\x08hostname\x18\r \x01(\x08H\x00\x12\x0c\n\x02ip\x18\x0e \x01(\x08H\x00\x12\x0e\n\x04ipv4\x18\x0f \x01(\x08H\x00\x12\x0e\n\x04ipv6\x18\x10 \x01(\x08H\x00\x12\r\n\x03uri\x18\x11 \x01(\x08H\x00\x12\x11\n\x07uri_ref\x18\x12 \x01(\x08H\x00\x42\x0c\n\nwell_known\"\xd8\x01\n\nBytesRules\x12\r\n\x05\x63onst\x18\x01 \x01(\x0c\x12\x0f\n\x07min_len\x18\x02 \x01(\x04\x12\x0f\n\x07max_len\x18\x03 \x01(\x04\x12\x0f\n\x07pattern\x18\x04 \x01(\t\x12\x0e\n\x06prefix\x18\x05 \x01(\x0c\x12\x0e\n\x06suffix\x18\x06 \x01(\x0c\x12\x10\n\x08\x63ontains\x18\x07 \x01(\x0c\x12\n\n\x02in\x18\x08 \x03(\x0c\x12\x0e\n\x06not_in\x18\t \x03(\x0c\x12\x0c\n\x02ip\x18\n \x01(\x08H\x00\x12\x0e\n\x04ipv4\x18\x0b \x01(\x08H\x00\x12\x0e\n\x04ipv6\x18\x0c \x01(\x08H\x00\x42\x0c\n\nwell_known\"L\n\tEnumRules\x12\r\n\x05\x63onst\x18\x01 \x01(\x05\x12\x14\n\x0c\x64\x65\x66ined_only\x18\x02 \x01(\x08\x12\n\n\x02in\x18\x03 \x03(\x05\x12\x0e\n\x06not_in\x18\x04 \x03(\x05\".\n\x0cMessageRules\x12\x0c\n\x04skip\x18\x01 \x01(\x08\x12\x10\n\x08required\x18\x02 \x01(\x08\"m\n\rRepeatedRules\x12\x11\n\tmin_items\x18\x01 \x01(\x04\x12\x11\n\tmax_items\x18\x02 \x01(\x04\x12\x0e\n\x06unique\x18\x03 \x01(\x08\x12&\n\x05items\x18\x04 \x01(\x0b\x32\x17.is.validate.FieldRules\"\x93\x01\n\x08MapRules\x12\x11\n\tmin_pairs\x18\x01 \x01(\x04\x12\x11\n\tmax_pairs\x18\x02 \x01(\x04\x12\x11\n\tno_sparse\x18\x03 \x01(\x08\x12%\n\x04keys\x18\x04 \x01(\x0b\x32\x17.is.validate.FieldRules\x12\'\n\x06values\x18\x05 \x01(\x0b\x32\x17.is.validate.FieldRules\"8\n\x08\x41nyRules\x12\x10\n\x08required\x18\x01 \x01(\x08\x12\n\n\x02in\x18\x02 \x03(\t\x12\x0e\n\x06not_in\x18\x03 \x03(\t\"\xbb\x02\n\rDurationRules\x12\x10\n\x08required\x18\x01 \x01(\x08\x12(\n\x05\x63onst\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12%\n\x02lt\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12&\n\x03lte\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12%\n\x02gt\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12&\n\x03gte\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12%\n\x02in\x18\x07 \x03(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06not_in\x18\x08 \x03(\x0b\x32\x19.google.protobuf.Duration\"\xba\x02\n\x0eTimestampRules\x12\x10\n\x08required\x18\x01 \x01(\x08\x12)\n\x05\x63onst\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x02lt\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03lte\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x02gt\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03gte\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06lt_now\x18\x07 \x01(\x08\x12\x0e\n\x06gt_now\x18\x08 \x01(\x08\x12)\n\x06within\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration:3\n\x08\x64isabled\x12\x1f.google.protobuf.MessageOptions\x18\x97\x8d\x38 \x01(\x08:1\n\x08required\x12\x1d.google.protobuf.OneofOptions\x18\x97\x8d\x38 \x01(\x08:G\n\x05rules\x12\x1d.google.protobuf.FieldOptions\x18\x97\x8d\x38 \x01(\x0b\x32\x17.is.validate.FieldRules')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'is_msgs.validate_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(disabled)
  google_dot_protobuf_dot_descriptor__pb2.OneofOptions.RegisterExtension(required)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(rules)

  DESCRIPTOR._options = None
  _FIELDRULES._serialized_start=139
  _FIELDRULES._serialized_end=1127
  _FLOATRULES._serialized_start=1129
  _FLOATRULES._serialized_end=1234
  _DOUBLERULES._serialized_start=1236
  _DOUBLERULES._serialized_end=1342
  _INT32RULES._serialized_start=1344
  _INT32RULES._serialized_end=1449
  _INT64RULES._serialized_start=1451
  _INT64RULES._serialized_end=1556
  _UINT32RULES._serialized_start=1558
  _UINT32RULES._serialized_end=1664
  _UINT64RULES._serialized_start=1666
  _UINT64RULES._serialized_end=1772
  _SINT32RULES._serialized_start=1774
  _SINT32RULES._serialized_end=1880
  _SINT64RULES._serialized_start=1882
  _SINT64RULES._serialized_end=1988
  _FIXED32RULES._serialized_start=1990
  _FIXED32RULES._serialized_end=2097
  _FIXED64RULES._serialized_start=2099
  _FIXED64RULES._serialized_end=2206
  _SFIXED32RULES._serialized_start=2208
  _SFIXED32RULES._serialized_end=2316
  _SFIXED64RULES._serialized_start=2318
  _SFIXED64RULES._serialized_end=2426
  _BOOLRULES._serialized_start=2428
  _BOOLRULES._serialized_end=2454
  _STRINGRULES._serialized_start=2457
  _STRINGRULES._serialized_end=2783
  _BYTESRULES._serialized_start=2786
  _BYTESRULES._serialized_end=3002
  _ENUMRULES._serialized_start=3004
  _ENUMRULES._serialized_end=3080
  _MESSAGERULES._serialized_start=3082
  _MESSAGERULES._serialized_end=3128
  _REPEATEDRULES._serialized_start=3130
  _REPEATEDRULES._serialized_end=3239
  _MAPRULES._serialized_start=3242
  _MAPRULES._serialized_end=3389
  _ANYRULES._serialized_start=3391
  _ANYRULES._serialized_end=3447
  _DURATIONRULES._serialized_start=3450
  _DURATIONRULES._serialized_end=3765
  _TIMESTAMPRULES._serialized_start=3768
  _TIMESTAMPRULES._serialized_end=4082
# @@protoc_insertion_point(module_scope)
